@@ -223,6 +223,19 @@ BasePlotCompositeWidget::createMainMenu()
 
   mp_mainMenu->addAction(show_processing_flow_action_p);
 
+  QAction *reset_plot_ranges_history_p =
+    new QAction("&Reset plot ranges history", dynamic_cast<QObject *>(this));
+  reset_plot_ranges_history_p->setStatusTip(
+    "Empty the list of plot ranges in the history (reset the backspace feature)");
+  reset_plot_ranges_history_p->setShortcut(QKeySequence("Ctrl+R, H"));
+
+  connect(reset_plot_ranges_history_p,
+          &QAction::triggered,
+          this,
+          &BasePlotCompositeWidget::resetPlotRangesHistory);
+
+  mp_mainMenu->addAction(reset_plot_ranges_history_p);
+
   mp_mainMenu->addSeparator();
 
   QAction *save_plot_to_clipboard_p =
@@ -417,6 +430,17 @@ BasePlotCompositeWidget::showProcessingFlow()
 }
 
 
+void
+BasePlotCompositeWidget::resetPlotRangesHistory()
+{
+
+  // We need to make sure the plot widget has its plot ranges history list
+  // emptied.
+
+  mp_plotWidget->resetAxesRangeHistory();
+}
+
+
 QString
 BasePlotCompositeWidget::getAnalysisStanza()
 {
