@@ -84,7 +84,7 @@ BasePlotWnd::BasePlotWnd(QWidget *parent,
 //! Destruct \c this BasePlotWnd instance.
 BasePlotWnd::~BasePlotWnd()
 {
-  // qDebug();
+   qDebug();
   writeSettings();
 }
 
@@ -125,7 +125,7 @@ BasePlotWnd::readSettings()
 void
 BasePlotWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
 {
-  // qDebug();
+  qDebug();
   writeSettings();
   hide();
 }
@@ -144,9 +144,8 @@ BasePlotWnd::initialize()
 {
   setWindowTitle(QString("mineXpert2 - %1").arg(m_title));
 
-  // This attribute make sure that the main window of the program is destroyed
-  // when it is closed. Effectively stopping the program.
-  setAttribute(Qt::WA_DeleteOnClose);
+  // We do not want to destroy on close !!!
+  //setAttribute(Qt::WA_DeleteOnClose);
 
   // The default window icon.
   QString pixmap_file_name = ":/images/icons/32x32/minexpert2.png";
@@ -1358,6 +1357,7 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
   QList<BasePlotCompositeWidget *> widget_list =
     findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
   std::vector<BaseTracePlotCompositeWidget *> pinned_down_widgets;
+
   for(int iter = 0; iter < widget_list.size(); ++iter)
     {
       BasePlotCompositeWidget *widget_p = widget_list.at(iter);
@@ -1371,8 +1371,16 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
           continue;
         }
 
+      // Ask a replotting with a record of the new axes ranges into the history.
       widget_p->mp_plotWidget->replotWithAxesRanges(
         x_axis_range, y_axis_range, static_cast<pappso::Axis>(which_plot_axis));
+
+      // We also need to update the context so that when we focus another plot
+      // widget, there is no jump in the plot, the plot was moved and has
+      // recorded the new ranges in the context and thus "start from there" when
+      // the trace is somehow panned or whatever. This fixes an issue reported
+      // by Kevin Hooijschuur. 
+      widget_p->mp_plotWidget->updateContextXandYAxisRanges();
     }
 }
 
